Module beamlit.models.latency_metric
====================================

Classes
-------

`LatencyMetric(global_histogram: beamlit.types.Unset | ForwardRef('HistogramBucket') = <beamlit.types.Unset object>, global_stats: beamlit.types.Unset | ForwardRef('HistogramStats') = <beamlit.types.Unset object>, histogram_per_code: beamlit.types.Unset | ForwardRef('HistogramBucket') = <beamlit.types.Unset object>, stats_per_code: beamlit.types.Unset | ForwardRef('HistogramStats') = <beamlit.types.Unset object>)`
:   Latency metrics
    
    Attributes:
        global_histogram (Union[Unset, HistogramBucket]): Histogram bucket
        global_stats (Union[Unset, HistogramStats]): Histogram stats
        histogram_per_code (Union[Unset, HistogramBucket]): Histogram bucket
        stats_per_code (Union[Unset, HistogramStats]): Histogram stats
    
    Method generated by attrs for class LatencyMetric.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `global_histogram`
    :

    `global_stats`
    :

    `histogram_per_code`
    :

    `stats_per_code`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :